Index: /code/trunk/src/modules/questsystem/QuestGUI.cc
===================================================================
--- /code/trunk/src/modules/questsystem/QuestGUI.cc	(revision 5747)
+++ /code/trunk/src/modules/questsystem/QuestGUI.cc	(revision 5748)
@@ -30,17 +30,13 @@
 
 #include <sstream>
+#include <CEGUIWindow.h>
+#include <CEGUIWindowManager.h>
 
 #include "core/CoreIncludes.h"
-#include "core/GUIManager.h"
-#include "infos/PlayerInfo.h"
 #include "Quest.h"
 #include "QuestHint.h"
-#include "QuestDescription.h" //Debug
 #include "QuestItem.h"
 #include "QuestGUINode.h"
 #include "QuestManager.h"
-
-#include <CEGUIWindow.h>
-#include <CEGUIWindowManager.h>
 
 namespace orxonox {
Index: /code/trunk/src/modules/questsystem/QuestGUI.h
===================================================================
--- /code/trunk/src/modules/questsystem/QuestGUI.h	(revision 5747)
+++ /code/trunk/src/modules/questsystem/QuestGUI.h	(revision 5748)
@@ -36,11 +36,11 @@
 
 #include "questsystem/QuestsystemPrereqs.h"
+
+#include <list>
+#include <map>
+#include <string>
 #include <CEGUIForwardRefs.h>
 
 #include "core/OrxonoxClass.h"
-
-#include <map>
-#include <string>
-#include <list>
 
 namespace orxonox {
@@ -95,5 +95,5 @@
             
             PlayerInfo* player_; //!< The player that owns the GUI.
-            CEGUI::WindowManager* windowManager_; //!< The CEGUI WindowManager. //TDO: needed?
+            CEGUI::WindowManager* windowManager_; //!< The CEGUI WindowManager. //TODO: needed?
             CEGUI::Window* rootWindow_; //!< The root CEGUI Window of the GUI.
 
Index: /code/trunk/src/modules/questsystem/QuestGUINode.cc
===================================================================
--- /code/trunk/src/modules/questsystem/QuestGUINode.cc	(revision 5747)
+++ /code/trunk/src/modules/questsystem/QuestGUINode.cc	(revision 5748)
@@ -31,6 +31,11 @@
 #include <sstream>
 
+#include <CEGUIWindowManager.h>
+#include <elements/CEGUIFrameWindow.h>
+#include <elements/CEGUIPushButton.h>
+#include <falagard/CEGUIFalWidgetLookFeel.h>
+#include <falagard/CEGUIFalWidgetLookManager.h>
+
 #include "core/CoreIncludes.h"
-#include "infos/PlayerInfo.h"
 #include "Quest.h"
 #include "QuestHint.h"
@@ -38,9 +43,4 @@
 #include "QuestDescription.h"
 #include "QuestGUI.h"
-
-#include <CEGUIWindow.h>
-#include <CEGUIWindowManager.h>
-#include <CEGUIFont.h>
-#include <CEGUI.h>
 
 namespace orxonox {
@@ -117,5 +117,5 @@
     }
 
-    int QuestGUINode::toggleVisibility(void)
+    void QuestGUINode::toggleVisibility(void)
     {
         
@@ -234,5 +234,5 @@
                         node->window_->setSize(CEGUI::UVector2(CEGUI::UDim(1.0, -13),CEGUI::UDim(0, 30)));
                         node->window_->setPosition(CEGUI::UVector2(CEGUI::UDim(0, 0),CEGUI::UDim(0, offset)));
-                        node->window_->setProperty("HorizontalAlignment", "Left"); // TDO: Get this working.
+                        node->window_->setProperty("HorizontalAlignment", "Left"); // TODO: Get this working.
                         window->addChildWindow(node->window_);
                         offset += 30;
Index: /code/trunk/src/modules/questsystem/QuestGUINode.h
===================================================================
--- /code/trunk/src/modules/questsystem/QuestGUINode.h	(revision 5747)
+++ /code/trunk/src/modules/questsystem/QuestGUINode.h	(revision 5748)
@@ -31,10 +31,9 @@
 
 #include "questsystem/QuestsystemPrereqs.h"
-#include <CEGUIForwardRefs.h>
-
-#include "core/OrxonoxClass.h"
 
 #include <list>
 #include <string>
+#include <CEGUIForwardRefs.h>
+#include "core/OrxonoxClass.h"
 
 
@@ -50,5 +49,5 @@
             virtual ~QuestGUINode(void);
     
-            int toggleVisibility(void);
+            void toggleVisibility(void);
 
             void getName(std::string & buffer); //!< Sets the input buffer to the name of the node.
Index: /code/trunk/src/modules/questsystem/QuestManager.cc
===================================================================
--- /code/trunk/src/modules/questsystem/QuestManager.cc	(revision 5747)
+++ /code/trunk/src/modules/questsystem/QuestManager.cc	(revision 5748)
@@ -34,16 +34,16 @@
 #include "QuestManager.h"
 
+#include <CEGUIWindow.h>
+
 #include "util/Exception.h"
 #include "core/CoreIncludes.h"
 #include "core/GUIManager.h"
 #include "core/ConsoleCommand.h"
-#include "core/input/InputManager.h" //TDO: Necessary?
-#include <CEGUIWindow.h>
+#include "infos/PlayerInfo.h"
 #include "overlays/GUIOverlay.h"
 
-#include "infos/PlayerInfo.h"
 #include "Quest.h"
 #include "QuestHint.h"
-#include "QuestItem.h" //TDO: Necessary?
+#include "QuestItem.h"
 
 namespace orxonox
Index: /code/trunk/src/modules/questsystem/notifications/NotificationManager.cc
===================================================================
--- /code/trunk/src/modules/questsystem/notifications/NotificationManager.cc	(revision 5747)
+++ /code/trunk/src/modules/questsystem/notifications/NotificationManager.cc	(revision 5748)
@@ -81,5 +81,5 @@
             return false;
 
-        std::time_t time = std::time(0); //TDO: Doesn't this expire? //!< Get current time.
+        std::time_t time = std::time(0); //TODO: Doesn't this expire? //!< Get current time.
 
         this->allNotificationsList_.insert(std::pair<std::time_t,Notification*>(time,notification));
@@ -96,5 +96,5 @@
         {
             std::set<std::string> set = it->first->getTargetsSet();
-            if(all || set.find(notification->getSender()) != set.end() || set.find(ALL) != set.end()) //TDO: Make sure this works.
+            if(all || set.find(notification->getSender()) != set.end() || set.find(ALL) != set.end()) //TODO: Make sure this works.
             {
                 this->notificationLists_[it->second]->insert(std::pair<std::time_t,Notification*>(time,notification)); //!< Insert the Notification in the Notifications list of the current NotificationListener.
@@ -123,5 +123,5 @@
         this->listenerList_[listener] = index; //!< Add the NotificationListener to the list of listeners.
 
-        std::set<std::string> set = listener->getTargetsSet(); //TDO: Works this?
+        std::set<std::string> set = listener->getTargetsSet(); //TODO: Works this?
 
         //! If all senders are the target of the listener, then the list of notification for that specific listener is te same as the list of all Notifications.
Index: /code/trunk/src/modules/questsystem/notifications/NotificationQueue.cc
===================================================================
--- /code/trunk/src/modules/questsystem/notifications/NotificationQueue.cc	(revision 5747)
+++ /code/trunk/src/modules/questsystem/notifications/NotificationQueue.cc	(revision 5748)
@@ -140,5 +140,5 @@
                 this->removeContainer(*it);
                 this->scroll(Vector2(0.0,-(1.1*this->getFontSize())));
-                it = this->containers_.begin(); //TDO: Needed?
+                it = this->containers_.begin(); //TODO: Needed?
             }
 
@@ -443,5 +443,5 @@
         {
             this->removeContainer(*it);
-            it = this->containers_.begin(); //TDO: Needed?
+            it = this->containers_.begin(); //TODO: Needed?
         }
     }

Index: /code/trunk/src/modules/questsystem/QuestManager.h
===================================================================
--- /code/trunk/src/modules/questsystem/QuestManager.h	(revision 5747)
+++ /code/trunk/src/modules/questsystem/QuestManager.h	(revision 5748)
@@ -65,5 +65,5 @@
 
             friend class ScopedSingleton<QuestManager, ScopeID::GSLevel>;
-            friend class QuestGUI; //TDO: better solution.
+            friend class QuestGUI; //TODO: better solution.
             //friend std::map<std::string, Quest*> & QuestGUI::getQuests(void);
 
@@ -94,5 +94,5 @@
             std::map<std::string, QuestHint*> hintMap_; //!< All QuestHints registered by their id's.
 
             //TDO: Call destructor of QuestGUI's on destruction of QuestManager?
             std::map<PlayerInfo*, QuestGUI*> questGUIs_; //!< All GUI's registered by the players.
 
@@ -94,5 +94,5 @@
             std::map<std::string, QuestHint*> hintMap_; //!< All QuestHints registered by their id's.
 
-            //TDO: Call destructor of QuestGUI's on destruction of QuestManager?
+            //TODO: Call destructor of QuestGUI's on destruction of QuestManager?
             std::map<PlayerInfo*, QuestGUI*> questGUIs_; //!< All GUI's registered by the players.
 